@@ -8,6 +8,12 @@
  * Use is subject to license terms specified in the COPYING file
  * distributed with the Net-SNMP package.
  */
+/*
+ * Portions of this file are copyrighted by:
+ * Copyright (C) 2007 Apple, Inc. All rights reserved.
+ * Use is subject to license terms specified in the COPYING file
+ * distributed with the Net-SNMP package.
+ */
 /*
  * @file table.h
  *
@@ -52,7 +58,7 @@ extern          "C" {
     typedef struct netsnmp_column_info_t {
         char            isRange;
  	/** only useful if isRange == 0 */
-        unsigned short  list_count;
+        char            list_count;
 
         union {
             unsigned int    range[2];
@@ -72,18 +78,18 @@ extern          "C" {
  * Table registration structure.
  */
     typedef struct netsnmp_table_registration_info_s {
-       /** list of varbinds with only 'type' set */
+ 	/** list of varbinds with only 'type' set */
         netsnmp_variable_list *indexes;
-       /** calculated automatically */
+ 	/** calculated automatically */
         unsigned int    number_indexes;
 
        /**
-         * the minimum and maximum columns numbers. If there are columns
-         * in-between which are not valid, use valid_columns to get
-         * automatic column range checking.
-         */
+        * the minimum columns number. If there are columns
+        * in-between which are not valid, use valid_columns to get
+        * automatic column range checking.
+        */
         unsigned int    min_column;
-       /** the maximum columns number */
+ 	/** the maximum columns number */
         unsigned int    max_column;
 
  	/** more details on columns */
@@ -100,13 +106,13 @@ extern          "C" {
  * The table request info structure.
  */
     typedef struct netsnmp_table_request_info_s {
-	/** 0 if OID not long enough */
+ 	/** 0 if OID not long enough */
         unsigned int    colnum;
-	/** 0 if failure to parse any */
+        /** 0 if failure to parse any */
         unsigned int    number_indexes;
-	/** contents freed by helper upon exit */
+ 	/** contents freed by helper upon exit */
         netsnmp_variable_list *indexes;
-	
+
         oid             index_oid[MAX_OID_LEN];
         size_t          index_oid_len;
         netsnmp_table_registration_info *reg_info;
@@ -115,15 +121,14 @@ extern          "C" {
     netsnmp_mib_handler
         *netsnmp_get_table_handler(netsnmp_table_registration_info
                                    *tabreq);
-    int             netsnmp_register_table(netsnmp_handler_registration
-                                           *reginfo,
-                                           netsnmp_table_registration_info
-                                           *tabreq);
-    int             netsnmp_table_build_oid(netsnmp_handler_registration
-                                            *reginfo,
-                                            netsnmp_request_info *reqinfo,
-                                            netsnmp_table_request_info
-                                            *table_info);
+    void  netsnmp_handler_owns_table_info(netsnmp_mib_handler *handler);
+    void  netsnmp_registration_owns_table_info(netsnmp_handler_registration *reg);
+    int   netsnmp_register_table(  netsnmp_handler_registration    *reginfo,
+                                   netsnmp_table_registration_info *tabreq);
+    int   netsnmp_unregister_table(netsnmp_handler_registration    *reginfo);
+    int   netsnmp_table_build_oid( netsnmp_handler_registration    *reginfo,
+                                   netsnmp_request_info            *reqinfo,
+                                   netsnmp_table_request_info   *table_info);
     int            
         netsnmp_table_build_oid_from_index(netsnmp_handler_registration
                                            *reginfo,
@@ -147,6 +152,10 @@ extern          "C" {
     netsnmp_table_registration_info
         *netsnmp_find_table_registration_info(netsnmp_handler_registration
                                               *reginfo);
+    netsnmp_table_registration_info *
+        netsnmp_table_registration_info_clone(netsnmp_table_registration_info *tri);
+    void netsnmp_table_registration_info_free(netsnmp_table_registration_info *);
+
     netsnmp_index * netsnmp_table_index_find_next_row(netsnmp_container *c,
                                                       netsnmp_table_request_info *tblreq);
 
@@ -158,13 +167,9 @@ extern          "C" {
 
 #define netsnmp_table_helper_add_index(tinfo, type) snmp_varlist_add_variable(&tinfo->indexes, NULL, 0, (u_char)type, NULL, 0);
 
-#if HAVE_STDARG_H
     void           
         netsnmp_table_helper_add_indexes(netsnmp_table_registration_info
                                          *tinfo, ...);
-#else
-    void            netsnmp_table_helper_add_indexes(va_alist);
-#endif
 
     int netsnmp_check_getnext_reply(netsnmp_request_info *request,
                                     oid * prefix, size_t prefix_len,
@@ -178,6 +183,14 @@ extern          "C" {
                                                 *reqinfo,
                                                 const u_char *
                                                 storage_name);
+	unsigned int
+		netsnmp_table_next_column(netsnmp_table_request_info *table_info);
+
+
+    int   netsnmp_sparse_table_register(netsnmp_handler_registration    *reginfo,
+                                        netsnmp_table_registration_info *tabreq);
+
+    netsnmp_mib_handler *netsnmp_sparse_table_handler_get(void);
 
 #ifdef __cplusplus
 }
